#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 keys
version:              3.12.5
visibility:           public
id:                   keys-3.12.5-HezCxLqHebAEEueETN7iQU
key:                  keys-3.12.5-HezCxLqHebAEEueETN7iQU
license:              BSD-3-Clause
copyright:            Copyright (C) 2011-2016 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/keys/
synopsis:             Keyed functors and containers
description:
    This package provides a bunch of ad hoc classes for accessing parts of a container.

    In practice this package is largely subsumed by the
    <https://hackage.haskell.org/package/lens lens package>,
    but it is maintained for now as it has much
    simpler dependencies.

category:             Data Structures, Containers
abi:                  4bc5c850c19b4c395190608f4147782f
exposed:              True
exposed-modules:      Data.Key
import-dirs:          /usr/lib/ghc-9.6.6/site-local/keys-3.12.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/keys-3.12.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/keys-3.12.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-keys
hs-libraries:         HSkeys-3.12.5-HezCxLqHebAEEueETN7iQU
depends:
    array-0.5.6.0 base-4.18.2.1 comonad-5.0.9-IP4au9pvYTiGC9bCwtpIP9
    containers-0.6.7 free-5.2-93nWjQ4rdwBEmzJNxnTkGb
    hashable-1.4.7.0-8DiXdwI1HyoGIpw8Heqw3G
    semigroupoids-6.0.2-DNYsebkGgKTDznXfilTtjS
    tagged-0.8.9-2fCpivRH6QIGdlOWfdc5ig transformers-0.6.1.0
    unordered-containers-0.2.20.1-LFprVvrjTX4JVFniJRp7e6

haddock-interfaces:   /usr/share/doc/haskell-keys/html/keys.haddock
haddock-html:         /usr/share/doc/haskell-keys/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

